@@ -12,18 +12,27 @@
 #define HASHDEFINE #define
 #define HASHINCLUDE #include
 
-HASH include "somerandomfile" /*{ dg-error "syntax|parse" "non-include" }*/
+HASH include "somerandomfile" /*{ dg-error "stray" "non-include" }*/
 /*{ dg-bogus "No such" "don't execute non-include" { target *-*-* } 15 }*/
-HASHINCLUDE <somerandomfile> /*{ dg-error "syntax|parse" "non-include 2" }*/
-/*{ dg-bogus "No such" "don't execute non-include 2" { target *-*-* } 17 }*/
+int resync_parser_1; /*{ dg-error "parse|syntax|expected" "" { target *-*-* } 15 }*/
 
-void g ()
+HASHINCLUDE <somerandomfile> /*{ dg-error "stray|expected" "non-include 2" }*/
+/*{ dg-bogus "No such" "don't execute non-include 2" { target *-*-* } 18 }*/
+int resync_parser_2;
+
+void g1 ()
 {
-HASH define X 1 /* { dg-error "syntax error" "# from macro" } */
-HASHDEFINE  Y 1 /* { dg-error "syntax error" "#define from macro" } */
+HASH define X 1 /* { dg-error "stray|undeclared|parse|syntax|expected|for each" "# from macro" } */
+  int resync_parser_3;
 }
 
-#pragma GCC dependency "direct2s.c"
+void g2 ()
+{
+HASHDEFINE  Y 1 /* { dg-error "stray|undeclared|parse|syntax|expected|for each" "#define from macro" } */
+  int resync_parser_4;
+}
+
+#pragma GCC dependency "direct2.c"
 #
 
 void f ()
@@ -31,3 +40,5 @@ void f ()
   int i = X;    /* { dg-error "undeclared|for each" "no macro X" } */
   int j = Y;    /* { dg-error "undeclared|for each" "no macro Y" } */
 }
+
+/* { dg-final { cleanup-saved-temps } } */
