@@ -5,7 +5,15 @@ typedef struct
   float b;
 }str_t;
 
+#ifdef STACK_SIZE
+#if STACK_SIZE > 8000
 #define N 1000
+#else
+#define N (STACK_SIZE/8)
+#endif
+#else
+#define N 1000
+#endif
 
 str_t *p;
 
@@ -15,7 +23,8 @@ main ()
   int i, sum;
 
   p = malloc (N * sizeof (str_t));
-
+  if (p == NULL)
+    return 0;
   for (i = 0; i < N; i++)
     p[i].b = i;
 
@@ -30,5 +39,5 @@ main ()
 }
 
 /*--------------------------------------------------------------------------*/
-/* { dg-final-use { scan-ipa-dump "Number of structures to transform is 1" "ipa_struct_reorg" } } */
+/* { dg-final-use { scan-ipa-dump "Number of structures to transform is 1" "ipa_struct_reorg" { xfail { "avr-*-*" } } } } */
 /* { dg-final-use { cleanup-ipa-dump "*" } } */
