@@ -1,12 +1,14 @@
-/* { dg-do compile } */ 
+/* { dg-do compile } */
 /* { dg-options "-O2 -fdump-tree-pre-stats" } */
 int p;
 int r;
-int a(void)
+
+__attribute__ ((noinline))
+static int a(void)
 {
   return p;
 }
-int main(int argc)
+int foo(int argc)
 {
   int q;
   q = a();
