@@ -2,8 +2,8 @@
 /* { dg-options "-Winline -O2 --param max-inline-insns-single=1" } */
 
 void big (void);
-inline int q(void)		
-{				/* { dg-warning "max-inline-insns-single" "" } */
+inline int q(void) /* { dg-warning "max-inline-insns-single" "" } */
+{
 	big();
 	big();
 	big();
