@@ -4,6 +4,13 @@
 
 static void avx_test (void);
 
+static void
+__attribute__ ((noinline))
+do_test (void)
+{
+  avx_test ();
+}
+
 int
 main ()
 {
@@ -13,9 +20,9 @@ main ()
     return 0;
 
   /* Run AVX test only if host has AVX support.  */
-  if (ecx & bit_AVX)
+  if ((ecx & (bit_AVX | bit_OSXSAVE)) == (bit_AVX | bit_OSXSAVE))
     {
-      avx_test ();
+      do_test ();
 #ifdef DEBUG
       printf ("PASSED\n");
 #endif
