@@ -1,25 +1,20 @@
-/* { dg-do run { target i?86-*-* x86_64-*-* } } */
+/* { dg-do run } */
 /* { dg-options "-O2 -msse" } */
+/* { dg-require-effective-target sse } */
+
+#include "sse-check.h"
+
 #include <xmmintrin.h>
-#include <stdlib.h>
 #include <stddef.h>
 #include <string.h>
-#include "../../gcc.dg/i386-cpuid.h"
 
-int
-main()
+static void
+sse_test (void)
 {
   int alignment, n;
   void *ptr;
   int errors = 0;
   const char test [] = "This is a test.";
-  unsigned long cpu_facilities;
-
-  cpu_facilities = i386_cpuid ();
-
-  if ((cpu_facilities & bit_SSE) != bit_SSE )
-    /* If host has no vector support, pass.  */
-    exit (0);
 
   for (alignment = 1; alignment <= (1 << 20); alignment += alignment)
     {
@@ -40,5 +35,4 @@ main()
    
   if (errors != 0)
     abort ();
-  exit (0);
 }
