@@ -2,14 +2,22 @@
 /* { dg-require-effective-target sse4 } */
 /* { dg-options "-O2 -msse4.1" } */
 
-#include "sse4_1-check.h"
+#ifndef CHECK_H
+#define CHECK_H "sse4_1-check.h"
+#endif
+
+#ifndef TEST
+#define TEST sse4_1_test
+#endif
+
+#include CHECK_H
 
 #include <smmintrin.h>
 
 #define NUM 64
 
 static void
-sse4_1_test (void)
+TEST (void)
 {
   union
     {
