@@ -5,17 +5,17 @@
 NOMIPS16 int
 f1 (int *z)
 {
-  return __sync_xor_and_fetch (z, 42);
+  return __sync_fetch_and_and (z, 42);
 }
 
 NOMIPS16 short
 f2 (short *z)
 {
-  return __sync_xor_and_fetch (z, 42);
+  return __sync_fetch_and_and (z, 42);
 }
 
 NOMIPS16 char
 f3 (char *z)
 {
-  return __sync_xor_and_fetch (z, 42);
+  return __sync_fetch_and_and (z, 42);
 }
